@@ -280,7 +280,7 @@ action_help (GSimpleAction *action,
   GError *error = NULL;
 
   gtk_show_uri (gtk_widget_get_screen (app->priv->window),
-                "ghelp:gnome-system-log", gtk_get_current_event_time (),
+                "help:gnome-system-log", gtk_get_current_event_time (),
                 &error);
 
   if (error) {
